summaryrefslogtreecommitdiffstats
path: root/ktouch
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:18:52 +0000
commit648ba4a456d3aad2825193ff8f3bd52a875783b5 (patch)
tree0b50d2253a0c85238cc4dcba5c4f949de3f0eb15 /ktouch
parent98a12d05a48814bec3870b9a6d5865475cfa1c95 (diff)
downloadtdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.tar.gz
tdeedu-648ba4a456d3aad2825193ff8f3bd52a875783b5.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1212481 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ktouch')
-rw-r--r--ktouch/src/ktouch.cpp44
-rw-r--r--ktouch/src/ktouch.h18
-rw-r--r--ktouch/src/ktouchchartwidget.h2
-rw-r--r--ktouch/src/ktouchcoloreditor_dlg.ui36
-rw-r--r--ktouch/src/ktouchdefaults.h2
-rw-r--r--ktouch/src/ktouchkey.h2
-rw-r--r--ktouch/src/ktouchkeyboard.cpp32
-rw-r--r--ktouch/src/ktouchkeyboard.h6
-rw-r--r--ktouch/src/ktouchkeyboardeditor.cpp6
-rw-r--r--ktouch/src/ktouchkeyboardeditor_dlg.ui14
-rw-r--r--ktouch/src/ktouchkeyboardwidget.cpp36
-rw-r--r--ktouch/src/ktouchkeyboardwidget.h16
-rw-r--r--ktouch/src/ktouchkeyconnector.h2
-rw-r--r--ktouch/src/ktouchkeys.h8
-rw-r--r--ktouch/src/ktouchlecture.cpp2
-rw-r--r--ktouch/src/ktouchlecture.h4
-rw-r--r--ktouch/src/ktouchlectureeditor.cpp2
-rw-r--r--ktouch/src/ktouchlectureeditor_dlg.ui44
-rw-r--r--ktouch/src/ktouchleveldata.h6
-rw-r--r--ktouch/src/ktouchopenrequest_dlg.ui20
-rw-r--r--ktouch/src/ktouchprefcolorslayout.ui40
-rw-r--r--ktouch/src/ktouchprefgenerallayout.ui24
-rw-r--r--ktouch/src/ktouchprefkeyboardlayout.ui14
-rw-r--r--ktouch/src/ktouchpreftraininglayout.ui22
-rw-r--r--ktouch/src/ktouchslideline.cpp6
-rw-r--r--ktouch/src/ktouchslideline.h2
-rw-r--r--ktouch/src/ktouchstatistics.cpp8
-rw-r--r--ktouch/src/ktouchstatistics_dlg.ui54
-rw-r--r--ktouch/src/ktouchstatisticsdata.cpp14
-rw-r--r--ktouch/src/ktouchstatisticsdata.h8
-rw-r--r--ktouch/src/ktouchstatus.cpp10
-rw-r--r--ktouch/src/ktouchstatus.h8
-rw-r--r--ktouch/src/ktouchstatuslayout.ui34
-rw-r--r--ktouch/src/ktouchtrainer.cpp22
-rw-r--r--ktouch/src/ktouchtrainer.h6
35 files changed, 287 insertions, 287 deletions
diff --git a/ktouch/src/ktouchchartwidget.h b/ktouch/src/ktouchchartwidget.h
index 212cd0a4..799a5a38 100644
--- a/ktouch/src/ktouchchartwidget.h
+++ b/ktouch/src/ktouchchartwidget.h
@@ -21,7 +21,7 @@
class KTouchTrainer;
-/// This is the chart widget and tqcontains all chart drawing code.
+/// This is the chart widget and contains all chart drawing code.
class KTouchChartWidget : public KPlotWidget {
Q_OBJECT
public:
diff --git a/ktouch/src/ktouchcoloreditor_dlg.ui b/ktouch/src/ktouchcoloreditor_dlg.ui
index 1d82f278..d6c4a0a7 100644
--- a/ktouch/src/ktouchcoloreditor_dlg.ui
+++ b/ktouch/src/ktouchcoloreditor_dlg.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchColorEditorDlg</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -31,7 +31,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
@@ -99,7 +99,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -129,7 +129,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout18</cstring>
+ <cstring>layout18</cstring>
</property>
<hbox>
<property name="name">
@@ -179,7 +179,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout14</cstring>
+ <cstring>layout14</cstring>
</property>
<grid>
<property name="name">
@@ -211,7 +211,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -246,7 +246,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -255,7 +255,7 @@
</spacer>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout10</cstring>
+ <cstring>layout10</cstring>
</property>
<grid>
<property name="name">
@@ -337,7 +337,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>30</width>
<height>20</height>
@@ -367,7 +367,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout24</cstring>
+ <cstring>layout24</cstring>
</property>
<grid>
<property name="name">
@@ -383,7 +383,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -400,7 +400,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -417,7 +417,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -426,7 +426,7 @@
</spacer>
<widget class="QLayoutWidget" row="0" column="0" rowspan="2" colspan="1">
<property name="name">
- <cstring>tqlayout22</cstring>
+ <cstring>layout22</cstring>
</property>
<grid>
<property name="name">
@@ -514,7 +514,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -525,7 +525,7 @@
</widget>
<widget class="QLayoutWidget" row="0" column="2">
<property name="name">
- <cstring>tqlayout20</cstring>
+ <cstring>layout20</cstring>
</property>
<grid>
<property name="name">
@@ -617,7 +617,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout28</cstring>
+ <cstring>layout28</cstring>
</property>
<hbox>
<property name="name">
@@ -792,7 +792,7 @@
<slot>updateClicked()</slot>
<slot>colorSchemeChanged(QListBoxItem * item)</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kpushbutton.h</includehint>
<includehint>kpushbutton.h</includehint>
diff --git a/ktouch/src/ktouchdefaults.h b/ktouch/src/ktouchdefaults.h
index 8f6631db..d66a1663 100644
--- a/ktouch/src/ktouchdefaults.h
+++ b/ktouch/src/ktouchdefaults.h
@@ -21,7 +21,7 @@ extern const unsigned int BEGINNER_SPEED; ///< Speed for rating in characters p
extern const unsigned int ADVANCED_SPEED; ///< Speed for rating in characters per minute.
extern const unsigned int PROFESSIONAL_SPEED; ///< Speed for rating in characters per minute.
-extern const int KEYBOARD_MARGIN; ///< The margin around the keybaord tqlayout.
+extern const int KEYBOARD_MARGIN; ///< The margin around the keybaord layout.
extern const int LCD_UPDATE_INTERVAL; ///< Update interval for LCD display and statistics.
diff --git a/ktouch/src/ktouchkey.h b/ktouch/src/ktouchkey.h
index f2090f24..011f4e4b 100644
--- a/ktouch/src/ktouchkey.h
+++ b/ktouch/src/ktouchkey.h
@@ -20,7 +20,7 @@
#include <tqpainter.h>
#include <tqdom.h>
-/// This class tqcontains information about one character on a key.
+/// This class contains information about one character on a key.
class KTouchKeyChar {
public:
/// Position of the character on the key.
diff --git a/ktouch/src/ktouchkeyboardeditor.cpp b/ktouch/src/ktouchkeyboardeditor.cpp
index af97725a..54f026bb 100644
--- a/ktouch/src/ktouchkeyboardeditor.cpp
+++ b/ktouch/src/ktouchkeyboardeditor.cpp
@@ -66,7 +66,7 @@ void KTouchKeyboardEditor::fontBtnClicked() {
titleEdit->setFont(f);
keyboardCommentEdit->setFont(f);
languageEdit->setFont(f);
- update(); // trigger tqrepaint of the keyboard.
+ update(); // trigger repaint of the keyboard.
setModified();
}
}
@@ -133,7 +133,7 @@ void KTouchKeyboardEditor::paintEvent(TQPaintEvent *) {
void KTouchKeyboardEditor::transfer_to_dialog() {
if (m_currentURL.isEmpty()) {
- titleEdit->setText( i18n("untitled keyboard tqlayout") );
+ titleEdit->setText( i18n("untitled keyboard layout") );
keyboardCommentEdit->setText("");
}
else {
@@ -173,7 +173,7 @@ void KTouchKeyboardEditor::transfer_to_dialog() {
void KTouchKeyboardEditor::transfer_from_dialog() {
m_keyboard.m_title = titleEdit->text();
- if (m_keyboard.m_title.isEmpty()) m_keyboard.m_title = i18n("untitled keyboard tqlayout");
+ if (m_keyboard.m_title.isEmpty()) m_keyboard.m_title = i18n("untitled keyboard layout");
m_keyboard.m_comment = keyboardCommentEdit->text();
m_keyboard.m_language = languageEdit->text();
}
diff --git a/ktouch/src/ktouchkeyboardeditor_dlg.ui b/ktouch/src/ktouchkeyboardeditor_dlg.ui
index 21633766..f6aa1009 100644
--- a/ktouch/src/ktouchkeyboardeditor_dlg.ui
+++ b/ktouch/src/ktouchkeyboardeditor_dlg.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchKeyboardEditorDlg</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -21,7 +21,7 @@
</property>
<widget class="QLayoutWidget" row="2" column="0" rowspan="1" colspan="2">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -45,7 +45,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -128,7 +128,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>100</height>
@@ -169,7 +169,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -290,7 +290,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>70</height>
@@ -389,7 +389,7 @@
<slot>removeBtnClicked()</slot>
<slot>keySelectionChanged(QListBoxItem*)</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kpushbutton.h</includehint>
<includehint>kpushbutton.h</includehint>
diff --git a/ktouch/src/ktouchkeyboardwidget.h b/ktouch/src/ktouchkeyboardwidget.h
index 8f9a1a13..047a7575 100644
--- a/ktouch/src/ktouchkeyboardwidget.h
+++ b/ktouch/src/ktouchkeyboardwidget.h
@@ -30,12 +30,12 @@ class KURL;
/** This is the keyboard widget at the bottom of the training screen.
* In addition to the painting functions this class has the member
* functions loadKeyboard() and saveKeyboard() which can read and write
- * a keyboard tqlayout from/into a file.<p>
+ * a keyboard layout from/into a file.<p>
* The keyboard is drawn in the paintEvent() member function. The
* resizing, that means the recalculation of m_shift is
* done in the resizeEvent() member function.<p>
* The state of keyboard and keys does not change while it is
- * tqrepainted or resized. Only when a new character has been typed
+ * repainted or resized. Only when a new character has been typed
* and the newKey() slot is called the state changes (and thus the
* activated keys and finger key animations etc.)
*/
@@ -44,14 +44,14 @@ class KTouchKeyboardWidget : public TQWidget {
public:
/// Constructor
KTouchKeyboardWidget(TQWidget *parent);
- /// Reads a keyboard tqlayout from the given URL.
+ /// Reads a keyboard layout from the given URL.
/// The function returns 'true' when the reading was successful or 'false' if not. In this
- /// case the optional parameter errorMsg tqcontains the error message.
+ /// case the optional parameter errorMsg contains the error message.
bool loadKeyboard(TQWidget * window, const KURL& url, TQString* errorMsg=NULL);
- /// Saves the keyboard tqlayout to the URL.
+ /// Saves the keyboard layout to the URL.
void saveKeyboard(TQWidget * window, const KURL& url);
- /// Applies preferences to the keyboard tqlayout and the keys.
- /// This means that the tqlayout is basically recreated and if the tqlayout type/language
+ /// Applies preferences to the keyboard layout and the keys.
+ /// This means that the layout is basically recreated and if the layout type/language
/// changed it will be reloaded.
void applyPreferences(TQWidget * window, bool silent);
@@ -89,7 +89,7 @@ class KTouchKeyboardWidget : public TQWidget {
int m_keyboardWidth; ///< The width of the keyboard (maximum of the sums of all keywidths in each line).
int m_keyboardHeight; ///< The height of the keyboard (sum of all key row heights).
double m_shift; ///< The horizontal shift for the keyboard.
- TQString m_currentLayout; ///< The name of the currently used tqlayout.
+ TQString m_currentLayout; ///< The name of the currently used layout.
TQChar m_nextKey; ///< The next to be pressed character.
bool m_hideKeyboard; ///< If true, the keyboard won't be shown.
diff --git a/ktouch/src/ktouchkeyconnector.h b/ktouch/src/ktouchkeyconnector.h
index be3d53e8..12793465 100644
--- a/ktouch/src/ktouchkeyconnector.h
+++ b/ktouch/src/ktouchkeyconnector.h
@@ -21,7 +21,7 @@
#include <tqvaluevector.h>
#include "ktouchkey.h"
- /// The KTouchKeyConnector class tqcontains the information about the character that has to
+ /// The KTouchKeyConnector class contains the information about the character that has to
/// be pressed and the keys on the keyboard that should be highlighted.
/// It associates a character with a target key and optionally a finger and/or control key.
class KTouchKeyConnector {
diff --git a/ktouch/src/ktouchkeys.h b/ktouch/src/ktouchkeys.h
index 76232a2f..68ffa959 100644
--- a/ktouch/src/ktouchkeys.h
+++ b/ktouch/src/ktouchkeys.h
@@ -25,7 +25,7 @@ class KTouchControlKey;
/** This is the base class for all keys (KTouchFingerKey, KTouchNormalKey and KTouchControlKey).
* Do not create instances of KTouchKey itself or you will get only blank keys. Note that the
- * KTouchKey class hierarchy tqcontains only the information for painting the keys. The connectivity
+ * KTouchKey class hierarchy contains only the information for painting the keys. The connectivity
* is handled using the KTouchKeyConnector.
*/
class KTouchBaseKey {
@@ -39,7 +39,7 @@ class KTouchBaseKey {
m_x(x), m_y(y), m_w(w), m_h(h), m_type(NORMAL_KEY) {}
/// Destructor.
virtual ~KTouchBaseKey() {}
- /// Paints the basic key tqshape using the painter p.
+ /// Paints the basic key shape using the painter p.
virtual void paint(TQPainter& p) const;
/// Recalculates the scaled position and size properties of the key.
void resize(double scale);
@@ -66,7 +66,7 @@ class KTouchBaseKey {
int m_wS; ///< The scaled width of the key.
int m_hS; ///< The scaled height of the key.
- KeyType m_type; ///< Stores the type of the key (convenience for saving of the keyboard tqlayout).
+ KeyType m_type; ///< Stores the type of the key (convenience for saving of the keyboard layout).
};
// ---------------------------------------------------------------------------------------
@@ -116,7 +116,7 @@ class KTouchFingerKey : public KTouchNormalKey {
/** This is a special or control key.
* This key acts as a modifier key to a normal key (for instance a shift key) and has a
- * different tqshape and painting routine then the normal keys. Therefore it is directly
+ * different shape and painting routine then the normal keys. Therefore it is directly
* derived from KTouchKey.
*/
class KTouchControlKey : public KTouchBaseKey {
diff --git a/ktouch/src/ktouchlecture.cpp b/ktouch/src/ktouchlecture.cpp
index 5f5dee7c..5f5d57de 100644
--- a/ktouch/src/ktouchlecture.cpp
+++ b/ktouch/src/ktouchlecture.cpp
@@ -210,7 +210,7 @@ bool KTouchLecture::readLecture(TQDomDocument& doc) {
void KTouchLecture::writeLecture(TQDomDocument& doc) const {
TQDomElement root = doc.createElement( "KTouchLecture" );
doc.appendChild(root);
- // Store title and ensure that the file tqcontains a title!
+ // Store title and ensure that the file contains a title!
TQDomElement title = doc.createElement("Title");
TQDomText titleText;
if (m_title.isEmpty()) titleText = doc.createTextNode( i18n("untitled lecture") );
diff --git a/ktouch/src/ktouchlecture.h b/ktouch/src/ktouchlecture.h
index 15c23989..9cc4cc6e 100644
--- a/ktouch/src/ktouchlecture.h
+++ b/ktouch/src/ktouchlecture.h
@@ -26,8 +26,8 @@ class KURL;
/// This class handles the lecture data and provides the lines to type.
///
-/// It tqcontains the level data (see KTouchLevelData). A lecture object
-/// tqcontains <b>ALWAYS</b> at least one lecture.<p>
+/// It contains the level data (see KTouchLevelData). A lecture object
+/// contains <b>ALWAYS</b> at least one lecture.<p>
/// The lecture data can be read and written using the member functions
/// readLecture() and writeLecture().<p>
/// During a training session the program will occasionally need a new
diff --git a/ktouch/src/ktouchlectureeditor.cpp b/ktouch/src/ktouchlectureeditor.cpp
index 36a340d1..e274732b 100644
--- a/ktouch/src/ktouchlectureeditor.cpp
+++ b/ktouch/src/ktouchlectureeditor.cpp
@@ -330,7 +330,7 @@ void KTouchLectureEditor::storeCurrentLevel() {
TQString currentLine;
for (unsigned int i=0; i<text.length(); ++i) {
TQChar c = text[i];
- if (c=='\t') c=' '; // tqreplace tabs with spaces
+ if (c=='\t') c=' '; // replace tabs with spaces
if (c=='\n') {
lines.append(currentLine);
currentLine = "";
diff --git a/ktouch/src/ktouchlectureeditor_dlg.ui b/ktouch/src/ktouchlectureeditor_dlg.ui
index b120c92e..a5008e97 100644
--- a/ktouch/src/ktouchlectureeditor_dlg.ui
+++ b/ktouch/src/ktouchlectureeditor_dlg.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchLectureEditorDlg</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -32,7 +32,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout7</cstring>
+ <cstring>layout7</cstring>
</property>
<hbox>
<property name="name">
@@ -87,7 +87,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>70</height>
@@ -109,7 +109,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout9</cstring>
+ <cstring>layout9</cstring>
</property>
<vbox>
<property name="name">
@@ -144,7 +144,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout8</cstring>
+ <cstring>layout8</cstring>
</property>
<hbox>
<property name="name">
@@ -155,7 +155,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout7</cstring>
+ <cstring>layout7</cstring>
</property>
<hbox>
<property name="name">
@@ -165,13 +165,13 @@
<property name="name">
<cstring>upBtn</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>35</width>
<height>28</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>32767</height>
@@ -188,13 +188,13 @@
<property name="name">
<cstring>downBtn</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>35</width>
<height>28</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>32767</height>
@@ -211,13 +211,13 @@
<property name="name">
<cstring>newBtn</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>35</width>
<height>28</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>32767</height>
@@ -242,13 +242,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>35</width>
<height>28</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>30</width>
<height>32767</height>
@@ -273,7 +273,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -286,7 +286,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout9</cstring>
+ <cstring>layout9</cstring>
</property>
<grid>
<property name="name">
@@ -334,7 +334,7 @@
</widget>
<widget class="QLayoutWidget" row="4" column="0" rowspan="1" colspan="2">
<property name="name">
- <cstring>tqlayout8</cstring>
+ <cstring>layout8</cstring>
</property>
<hbox>
<property name="name">
@@ -358,7 +358,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -383,7 +383,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -486,7 +486,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout35</cstring>
+ <cstring>layout35</cstring>
</property>
<hbox>
<property name="name">
@@ -510,7 +510,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>248</width>
<height>20</height>
@@ -664,7 +664,7 @@
<slot>setModified()</slot>
<slot>fontBtnClicked()</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>klistview.h</includehint>
diff --git a/ktouch/src/ktouchleveldata.h b/ktouch/src/ktouchleveldata.h
index 16c6c0bf..a84743c2 100644
--- a/ktouch/src/ktouchleveldata.h
+++ b/ktouch/src/ktouchleveldata.h
@@ -25,11 +25,11 @@
class TQDomDocument;
class TQDomElement;
-/// This class tqcontains the data of one level in a lecture and provides
+/// This class contains the data of one level in a lecture and provides
/// access to the lines of that level.
///
-/// A lecture (KTouchLecture) typically tqcontains multiple levels. Each
-/// level tqcontains a level description, a string with the
+/// A lecture (KTouchLecture) typically contains multiple levels. Each
+/// level contains a level description, a string with the
/// newly introduced characters and several lines of training text.
/// There is ALWAYS at least one line of training text in the level!<p>
/// During a training session you might want to retrieve a certain line of
diff --git a/ktouch/src/ktouchopenrequest_dlg.ui b/ktouch/src/ktouchopenrequest_dlg.ui
index 0e22c9db..38ff057e 100644
--- a/ktouch/src/ktouchopenrequest_dlg.ui
+++ b/ktouch/src/ktouchopenrequest_dlg.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchOpenRequestDlg</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -42,7 +42,7 @@
<property name="name">
<cstring>currentRadioBtn</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>28</height>
@@ -56,7 +56,7 @@
<property name="name">
<cstring>presetRadioBtn</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>28</height>
@@ -89,7 +89,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -106,7 +106,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -115,7 +115,7 @@
</spacer>
<widget class="QLayoutWidget" row="2" column="1">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -151,7 +151,7 @@
<property name="name">
<cstring>openFileRadioBtn</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>28</height>
@@ -165,7 +165,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<hbox>
<property name="name">
@@ -181,7 +181,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -278,7 +278,7 @@
<slot>radioBtnChanged()</slot>
<slot>browseBtnClicked()</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>klineedit.h</includehint>
<includehint>kpushbutton.h</includehint>
diff --git a/ktouch/src/ktouchprefcolorslayout.ui b/ktouch/src/ktouchprefcolorslayout.ui
index 2712d427..5b475da0 100644
--- a/ktouch/src/ktouchprefcolorslayout.ui
+++ b/ktouch/src/ktouchprefcolorslayout.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchPrefColorsLayout</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -35,7 +35,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -59,7 +59,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -120,7 +120,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout9</cstring>
+ <cstring>layout9</cstring>
</property>
<grid>
<property name="name">
@@ -130,7 +130,7 @@
<property name="name">
<cstring>kcfg_TeacherBackgroundColor</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>40</width>
<height>0</height>
@@ -166,7 +166,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>40</width>
<height>0</height>
@@ -189,7 +189,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -206,7 +206,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -217,7 +217,7 @@
<property name="name">
<cstring>kcfg_StudentTextColor</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>40</width>
<height>0</height>
@@ -245,7 +245,7 @@
<property name="name">
<cstring>kcfg_StudentBackgroundColor</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>40</width>
<height>0</height>
@@ -273,7 +273,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -306,7 +306,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>34</width>
<height>20</height>
@@ -333,7 +333,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -353,7 +353,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<hbox>
<property name="name">
@@ -369,7 +369,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>140</width>
<height>20</height>
@@ -391,7 +391,7 @@
<property name="enabled">
<bool>true</bool>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>40</width>
<height>0</height>
@@ -424,7 +424,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -446,7 +446,7 @@
<property name="enabled">
<bool>true</bool>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>40</width>
<height>0</height>
@@ -485,7 +485,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -504,7 +504,7 @@
<tabstop>kcfg_ErrorBackgroundColor</tabstop>
<tabstop>kcfg_CurrentColorScheme</tabstop>
</tabstops>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcolorbutton.h</includehint>
<includehint>kcolorbutton.h</includehint>
diff --git a/ktouch/src/ktouchprefgenerallayout.ui b/ktouch/src/ktouchprefgenerallayout.ui
index 01b2afcb..b62a5e81 100644
--- a/ktouch/src/ktouchprefgenerallayout.ui
+++ b/ktouch/src/ktouchprefgenerallayout.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchPrefGeneralLayout</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -82,7 +82,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<grid>
<property name="name">
@@ -106,7 +106,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>227</width>
<height>20</height>
@@ -117,7 +117,7 @@
<property name="name">
<cstring>kcfg_SlidingSpeed</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>20</height>
@@ -149,7 +149,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -184,7 +184,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -193,7 +193,7 @@
</spacer>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -238,7 +238,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -247,7 +247,7 @@
</spacer>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<grid>
<property name="name">
@@ -271,7 +271,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>114</width>
<height>20</height>
@@ -323,7 +323,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>31</width>
<height>30</height>
@@ -334,7 +334,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kfontrequester.h</includehint>
</includehints>
diff --git a/ktouch/src/ktouchprefkeyboardlayout.ui b/ktouch/src/ktouchprefkeyboardlayout.ui
index 0691ef64..34851276 100644
--- a/ktouch/src/ktouchprefkeyboardlayout.ui
+++ b/ktouch/src/ktouchprefkeyboardlayout.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchPrefKeyboardLayout</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -65,7 +65,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -74,7 +74,7 @@
</spacer>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<vbox>
<property name="name">
@@ -88,10 +88,10 @@
<string>Override keyboard fonts</string>
</property>
<property name="toolTip" stdset="0">
- <string>If checked you can specify your own keyboard font instead of the predefined one of the keyboard tqlayout.</string>
+ <string>If checked you can specify your own keyboard font instead of the predefined one of the keyboard layout.</string>
</property>
<property name="whatsThis" stdset="0">
- <string>Every keyboard tqlayout may specify its own font. If the predefined font of a certain keyboard tqlayout does not work or you would like to have your own, check this button. You may then choose your own font that will be used to draw the characters on the keys.</string>
+ <string>Every keyboard layout may specify its own font. If the predefined font of a certain keyboard layout does not work or you would like to have your own, check this button. You may then choose your own font that will be used to draw the characters on the keys.</string>
</property>
</widget>
<widget class="QLabel">
@@ -121,7 +121,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>30</height>
@@ -135,7 +135,7 @@
<slots>
<slot>fontChooseBtnClicked()</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kfontrequester.h</includehint>
</includehints>
diff --git a/ktouch/src/ktouchpreftraininglayout.ui b/ktouch/src/ktouchpreftraininglayout.ui
index a2e85fad..19fe985c 100644
--- a/ktouch/src/ktouchpreftraininglayout.ui
+++ b/ktouch/src/ktouchpreftraininglayout.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchPrefTrainingLayout</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -51,7 +51,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -60,7 +60,7 @@
</spacer>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout1</cstring>
+ <cstring>layout1</cstring>
</property>
<grid>
<property name="name">
@@ -121,7 +121,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -146,7 +146,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -165,7 +165,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -174,7 +174,7 @@
</spacer>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<grid>
<property name="name">
@@ -235,7 +235,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -252,7 +252,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
@@ -310,7 +310,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -321,7 +321,7 @@
</widget>
<customwidgets>
</customwidgets>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>knuminput.h</includehint>
<includehint>knuminput.h</includehint>
diff --git a/ktouch/src/ktouchslideline.cpp b/ktouch/src/ktouchslideline.cpp
index fe65f2a9..3071cc52 100644
--- a/ktouch/src/ktouchslideline.cpp
+++ b/ktouch/src/ktouchslideline.cpp
@@ -237,8 +237,8 @@ void KTouchSlideLine::resizeEvent ( TQResizeEvent * ) {
KD_DEBUG( "[KTouchSlideLine::resizeEvent]" << endl );
// required input member variables: none
- // when the widget is resized, the whole tqgeometry is tqinvalidated, so we do:
- // 1. recalculate and store the tqgeometry of the sliding lines
+ // when the widget is resized, the whole geometry is invalidated, so we do:
+ // 1. recalculate and store the geometry of the sliding lines
// 2. resize the font
// 3. recreate the sliding lines (this is done from the resizeFont() function
@@ -443,7 +443,7 @@ void KTouchSlideLine::updateSlidingLines() {
KD_DEBUG( " m_studentPixmap = " << w+100 << " x " << h << endl );
// update (draw) student line and calculate coordinates needed for sliding
- tqrepaint(true); // trigger a paint event to erase the background
+ repaint(true); // trigger a paint event to erase the background
updateStudentLine();
}
// ----------------------------------------------------------------------------
diff --git a/ktouch/src/ktouchslideline.h b/ktouch/src/ktouchslideline.h
index c636338f..b1466b7e 100644
--- a/ktouch/src/ktouchslideline.h
+++ b/ktouch/src/ktouchslideline.h
@@ -82,7 +82,7 @@ class KTouchSlideLine : public TQWidget {
/// @see slide()
void paintEvent( TQPaintEvent * );
/// Will be called when the widget is resized.
- /// This event will first recalculate the tqgeometry of the sliding lines.
+ /// This event will first recalculate the geometry of the sliding lines.
/// Then the font size will be updated and through that, the sliding lines will be
/// updated.
void resizeEvent ( TQResizeEvent * );
diff --git a/ktouch/src/ktouchstatistics.cpp b/ktouch/src/ktouchstatistics.cpp
index 53d57315..dbd807a6 100644
--- a/ktouch/src/ktouchstatistics.cpp
+++ b/ktouch/src/ktouchstatistics.cpp
@@ -328,7 +328,7 @@ void KTouchStatistics::updateChartTab() {
{
double t = m_currSessionStats.m_elapsedTime;
double wpm = m_currSessionStats.m_words/t*60.0;
- double tp = TQDateTime::tqcurrentDateTime().toTime_t()/(3600.0*24);
+ double tp = TQDateTime::currentDateTime().toTime_t()/(3600.0*24);
data.push_back(std::make_pair(tp, wpm) );
}
chartWidget->LeftAxis.setLabel( i18n("Words per minute") );
@@ -352,7 +352,7 @@ void KTouchStatistics::updateChartTab() {
{
double t = m_currSessionStats.m_elapsedTime;
double cpm = m_currSessionStats.m_correctChars/t*60.0;
- double tp = TQDateTime::tqcurrentDateTime().toTime_t()/(3600.0*24);
+ double tp = TQDateTime::currentDateTime().toTime_t()/(3600.0*24);
data.push_back(std::make_pair(tp, cpm) );
}
chartWidget->LeftAxis.setLabel( i18n("Characters per minute") );
@@ -376,7 +376,7 @@ void KTouchStatistics::updateChartTab() {
{
double tc = m_currSessionStats.m_totalChars;
double corr = m_currSessionStats.m_correctChars/tc;
- double tp = TQDateTime::tqcurrentDateTime().toTime_t()/(3600.0*24);
+ double tp = TQDateTime::currentDateTime().toTime_t()/(3600.0*24);
data.push_back(std::make_pair(tp, corr) );
}
chartWidget->LeftAxis.setLabel( i18n("Correctness") );
@@ -407,7 +407,7 @@ void KTouchStatistics::updateChartTab() {
double t = m_currSessionStats.m_elapsedTime;
double cpm = m_currSessionStats.m_correctChars/t*60.0;
double skill = corr*cpm;
- double tp = TQDateTime::tqcurrentDateTime().toTime_t()/(3600.0*24);
+ double tp = TQDateTime::currentDateTime().toTime_t()/(3600.0*24);
data.push_back(std::make_pair(tp, skill) );
}
chartWidget->LeftAxis.setLabel( i18n("Skill") );
diff --git a/ktouch/src/ktouchstatistics_dlg.ui b/ktouch/src/ktouchstatistics_dlg.ui
index 8220a0e3..761fd908 100644
--- a/ktouch/src/ktouchstatistics_dlg.ui
+++ b/ktouch/src/ktouchstatistics_dlg.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>KTouchStatisticsDlg</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -69,7 +69,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout7</cstring>
+ <cstring>layout7</cstring>
</property>
<grid>
<property name="name">
@@ -127,7 +127,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout28</cstring>
+ <cstring>layout28</cstring>
</property>
<grid>
<property name="name">
@@ -172,7 +172,7 @@
<property name="name">
<cstring>elapsedTimeLCD</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -189,7 +189,7 @@
<property name="name">
<cstring>totalCharsLCD</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -206,7 +206,7 @@
<property name="name">
<cstring>wrongCharsLCD</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -223,7 +223,7 @@
<property name="name">
<cstring>wordsLCD</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -264,7 +264,7 @@
<property name="name">
<cstring>frame4</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>20</width>
<height>0</height>
@@ -414,7 +414,7 @@
<property name="name">
<cstring>charSpeedLCD</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -431,7 +431,7 @@
<property name="name">
<cstring>wordSpeedLCD</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -479,7 +479,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -515,7 +515,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout8</cstring>
+ <cstring>layout8</cstring>
</property>
<grid>
<property name="name">
@@ -573,7 +573,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout28_2</cstring>
+ <cstring>layout28_2</cstring>
</property>
<grid>
<property name="name">
@@ -618,7 +618,7 @@
<property name="name">
<cstring>elapsedTimeLCDLevel</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -632,7 +632,7 @@
<property name="name">
<cstring>totalCharsLCDLevel</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -646,7 +646,7 @@
<property name="name">
<cstring>wrongCharsLCDLevel</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -660,7 +660,7 @@
<property name="name">
<cstring>wordsLCDLevel</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -698,7 +698,7 @@
<property name="name">
<cstring>frame4_2</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>20</width>
<height>0</height>
@@ -848,7 +848,7 @@
<property name="name">
<cstring>charSpeedLCDLevel</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -862,7 +862,7 @@
<property name="name">
<cstring>wordSpeedLCDLevel</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>50</width>
<height>32767</height>
@@ -904,7 +904,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>89</height>
@@ -940,7 +940,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<hbox>
<property name="name">
@@ -1060,7 +1060,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -1189,7 +1189,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -1205,7 +1205,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<hbox>
<property name="name">
@@ -1232,7 +1232,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>40</width>
<height>20</height>
@@ -1277,7 +1277,7 @@
<data format="PNG" length="1525">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</data>
</image>
</images>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
<includehints>
<includehint>kcombobox.h</includehint>
<includehint>ktouchchartwidget.h</includehint>
diff --git a/ktouch/src/ktouchstatisticsdata.h b/ktouch/src/ktouchstatisticsdata.h
index a0602c11..15ab2f82 100644
--- a/ktouch/src/ktouchstatisticsdata.h
+++ b/ktouch/src/ktouchstatisticsdata.h
@@ -30,7 +30,7 @@
class TQWidget;
-// This file tqcontains all class declarations dealing with the statistics obtained in KTouch.
+// This file contains all class declarations dealing with the statistics obtained in KTouch.
// *** KTouchCharStats ***
@@ -79,7 +79,7 @@ TQTextStream& operator<<(TQTextStream &out, const KTouchCharStats &ch);
/// Contains the complete statistics obtained for a single level.
///
-/// This class tqcontains the statistics for a single run through a single level. It tqcontains the
+/// This class contains the statistics for a single run through a single level. It contains the
/// statistics for all characters that have been mistyped in this level, the typing time, the word count,
/// correct and total character count etc.
class KTouchLevelStats {
@@ -122,7 +122,7 @@ class KTouchLevelStats {
/// Contains the complete statistics obtained for a single training session (spanning several levels).
///
-/// This class tqcontains the statistics for a complete training session of a single lecture but may include several levels.
+/// This class contains the statistics for a complete training session of a single lecture but may include several levels.
class KTouchSessionStats {
public:
/// Default constructor
@@ -156,7 +156,7 @@ class KTouchSessionStats {
/// Contains the complete statistics obtained over time for a certain training lecture.
///
-/// This class tqcontains the statistics for a complete training lecture including separate level statistics as well
+/// This class contains the statistics for a complete training lecture including separate level statistics as well
/// as session statistics.
class KTouchLectureStats {
public:
diff --git a/ktouch/src/ktouchstatus.cpp b/ktouch/src/ktouchstatus.cpp
index 442deba5..94d11894 100644
--- a/ktouch/src/ktouchstatus.cpp
+++ b/ktouch/src/ktouchstatus.cpp
@@ -20,13 +20,13 @@
#include <kpushbutton.h>
#include "prefs.h"
-KTouchtqStatus::KTouchtqStatus(TQWidget *parent)
- : KTouchtqStatusLayout(parent)
+KTouchStatus::KTouchStatus(TQWidget *parent)
+ : KTouchStatusLayout(parent)
{
applyPreferences();
}
-void KTouchtqStatus::applyPreferences() {
+void KTouchStatus::applyPreferences() {
if (Prefs::autoLevelChange()) {
levelUpBtn->setEnabled( !Prefs::disableManualLevelChange() );
levelDownBtn->setEnabled( !Prefs::disableManualLevelChange() );
@@ -37,11 +37,11 @@ void KTouchtqStatus::applyPreferences() {
}
}
-void KTouchtqStatus::setNewChars(const TQString& newChars) {
+void KTouchStatus::setNewChars(const TQString& newChars) {
newCharsLabel->setText(newChars);
}
-void KTouchtqStatus::updatetqStatus(unsigned int level, double correctness) {
+void KTouchStatus::updateStatus(unsigned int level, double correctness) {
levelLCD->display(static_cast<int>(level)+1); // +1 because our level variable ranges from 0...n-1
correctnessBar->setProgress(static_cast<int>(correctness*100) );
}
diff --git a/ktouch/src/ktouchstatuslayout.ui b/ktouch/src/ktouchstatuslayout.ui
index 7d64ddf5..80b29f9f 100644
--- a/ktouch/src/ktouchstatuslayout.ui
+++ b/ktouch/src/ktouchstatuslayout.ui
@@ -1,10 +1,10 @@
<!DOCTYPE UI><UI version="3.3" stdsetdef="1">
-<class>KTouchtqStatusLayout</class>
+<class>KTouchStatusLayout</class>
<widget class="QWidget">
<property name="name">
- <cstring>KTouchtqStatusLayout</cstring>
+ <cstring>KTouchStatusLayout</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -40,7 +40,7 @@
</property>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -58,7 +58,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>30</height>
@@ -85,7 +85,7 @@
</widget>
<widget class="QLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<vbox>
<property name="name">
@@ -95,7 +95,7 @@
<property name="name">
<cstring>levelUpBtn</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>20</width>
<height>20</height>
@@ -112,7 +112,7 @@
<property name="name">
<cstring>levelDownBtn</cstring>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>20</width>
<height>20</height>
@@ -160,7 +160,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>2</height>
@@ -171,7 +171,7 @@
<property name="name">
<cstring>speedLCD</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>30</height>
@@ -203,7 +203,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>2</height>
@@ -233,7 +233,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>2</height>
@@ -261,7 +261,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>2</height>
@@ -291,7 +291,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>2</height>
@@ -321,7 +321,7 @@
<property name="scaledContents">
<bool>true</bool>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
<property name="hAlign" stdset="0">
@@ -337,7 +337,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>2</height>
@@ -356,5 +356,5 @@
<slot>startKTouch()</slot>
<slot>stopKTouch()</slot>
</slots>
-<tqlayoutdefaults spacing="6" margin="11"/>
+<layoutdefaults spacing="6" margin="11"/>
</UI>
diff --git a/ktouch/src/ktouchtrainer.cpp b/ktouch/src/ktouchtrainer.cpp
index 95df9e20..7ed140ca 100644
--- a/ktouch/src/ktouchtrainer.cpp
+++ b/ktouch/src/ktouchtrainer.cpp
@@ -31,7 +31,7 @@
#include "ktouchdefaults.h"
#include "prefs.h"
-KTouchTrainer::KTouchTrainer(KTouchtqStatus *status, KTouchSlideLine *slideLine, KTouchKeyboardWidget *keyboard, KTouchLecture *lecture)
+KTouchTrainer::KTouchTrainer(KTouchStatus *status, KTouchSlideLine *slideLine, KTouchKeyboardWidget *keyboard, KTouchLecture *lecture)
: TQObject(),
m_trainingTimer(new TQTimer),
m_statusWidget(status),
@@ -233,7 +233,7 @@ void KTouchTrainer::enterPressed() {
void KTouchTrainer::updateWidgets() {
// update status widget
- m_statusWidget->updatetqStatus(m_level, m_levelStats.correctness());
+ m_statusWidget->updateStatus(m_level, m_levelStats.correctness());
// update slide line widget
m_slideLineWidget->setStudentText(m_studentText);
// update keyboard widget -> show next to be pressed char.
@@ -270,7 +270,7 @@ void KTouchTrainer::startTraining(bool keepLevel) {
gotoFirstLine();
updateStatusBarMessage(i18n("Starting training session: Waiting for first keypress...") );
updateStatusBar();
- m_statusWidget->updatetqStatus(m_level, 1);
+ m_statusWidget->updateStatus(m_level, 1);
m_statusWidget->speedLCD->display( 0 );
m_trainingPaused=true; // Go into "Pause" mode
m_trainingTimer->stop(); // Training timer will be started on first keypress.
@@ -285,7 +285,7 @@ void KTouchTrainer::pauseTraining() {
m_trainingPaused=true;
m_trainingTimer->stop();
m_slideLineWidget->setCursorTimerEnabled(false);
- m_statusWidget->updatetqStatus(m_level, m_levelStats.correctness());
+ m_statusWidget->updateStatus(m_level, m_levelStats.correctness());
m_statusWidget->speedLCD->display( m_levelStats.charSpeed() );
updateStatusBarMessage(i18n("Training session paused. Training continues on next keypress...") );
updateStatusBar();
@@ -298,7 +298,7 @@ void KTouchTrainer::pauseTraining() {
void KTouchTrainer::continueTraining() {
m_trainingPaused=false;
m_slideLineWidget->setCursorTimerEnabled(true);
- m_statusWidget->updatetqStatus(m_level, m_levelStats.correctness() );
+ m_statusWidget->updateStatus(m_level, m_levelStats.correctness() );
m_statusWidget->speedLCD->display( m_levelStats.charSpeed() );
updateStatusBarMessage(i18n("Training session! The time is running...") );
updateStatusBar();
@@ -317,12 +317,12 @@ void KTouchTrainer::storeTrainingStatistics() {
// are there level stats to be stored?
if (m_levelStats.m_elapsedTime != 0) {
//kdDebug() << "[KTouchTrainer::storeTrainingStatistics] Storing level statistics!" << endl;
- m_levelStats.m_timeRecorded = TQDateTime::tqcurrentDateTime();
+ m_levelStats.m_timeRecorded = TQDateTime::currentDateTime();
data.m_levelStats.push_back( m_levelStats );
}
if (m_sessionStats.m_elapsedTime != 0) {
//kdDebug() << "[KTouchTrainer::storeTrainingStatistics] Storing session statistics!" << endl;
- m_sessionStats.m_timeRecorded = TQDateTime::tqcurrentDateTime();
+ m_sessionStats.m_timeRecorded = TQDateTime::currentDateTime();
data.m_sessionStats.push_back( m_sessionStats );
}
}
@@ -412,7 +412,7 @@ void KTouchTrainer::newLine() {
// ----------------------------------------------------------------------------
void KTouchTrainer::updateStatusBar() const {
- KTouchPtr->changetqStatusbarStats(m_levelStats.m_correctChars, m_levelStats.m_totalChars,
+ KTouchPtr->changeStatusbarStats(m_levelStats.m_correctChars, m_levelStats.m_totalChars,
m_levelStats.m_words + m_wordsInCurrentLine,
m_sessionStats.m_correctChars, m_sessionStats.m_totalChars,
m_sessionStats.m_words + m_wordsInCurrentLine);
@@ -420,7 +420,7 @@ void KTouchTrainer::updateStatusBar() const {
// ----------------------------------------------------------------------------
void KTouchTrainer::updateStatusBarMessage(const TQString& message) const {
- KTouchPtr->changetqStatusbarMessage(message);
+ KTouchPtr->changeStatusbarMessage(message);
}
// ----------------------------------------------------------------------------
@@ -487,7 +487,7 @@ void KTouchTrainer::statsChangeLevel() {
// are there level stats to be stored?
if (m_levelStats.m_elapsedTime != 0) {
//kdDebug() << "[KTouchTrainer::storeTrainingStatistics] Storing level statistics!" << endl;
- m_levelStats.m_timeRecorded = TQDateTime::tqcurrentDateTime();
+ m_levelStats.m_timeRecorded = TQDateTime::currentDateTime();
data.m_levelStats.push_back( m_levelStats );
}
// clear level stats
@@ -497,6 +497,6 @@ void KTouchTrainer::statsChangeLevel() {
// remember level in session stats
m_sessionStats.m_levelNums.insert(m_level);
// show new level (in status widet) and 100% correctness
- m_statusWidget->updatetqStatus(m_level, 1);
+ m_statusWidget->updateStatus(m_level, 1);
}
// ----------------------------------------------------------------------------
diff --git a/ktouch/src/ktouchtrainer.h b/ktouch/src/ktouchtrainer.h
index 1fd2fd1f..f625d67b 100644
--- a/ktouch/src/ktouchtrainer.h
+++ b/ktouch/src/ktouchtrainer.h
@@ -23,7 +23,7 @@
class TQTimer;
-class KTouchtqStatus;
+class KTouchStatus;
class KTouchSlideLine;
class KTouchKeyboardWidget;
class KTouchLecture;
@@ -61,7 +61,7 @@ class KTouchTrainer : public TQObject {
Q_OBJECT
public:
/// Constructor.
- KTouchTrainer(KTouchtqStatus *status, KTouchSlideLine *slideLine, KTouchKeyboardWidget *keyboard, KTouchLecture *lecture);
+ KTouchTrainer(KTouchStatus *status, KTouchSlideLine *slideLine, KTouchKeyboardWidget *keyboard, KTouchLecture *lecture);
/// Destructor
virtual ~KTouchTrainer();
/// Jumps to the first line in the current level (m_level) (Note: has no effect on the training statistics).
@@ -148,7 +148,7 @@ class KTouchTrainer : public TQObject {
/// right before a new level and new line is started).
void statsChangeLevel();
- KTouchtqStatus *m_statusWidget; ///< Pointer to the status widget on top of the main window.
+ KTouchStatus *m_statusWidget; ///< Pointer to the status widget on top of the main window.
KTouchSlideLine *m_slideLineWidget; ///< Pointer to the sliding line widget.
KTouchKeyboardWidget *m_keyboardWidget; ///< Pointer to the keyboard widget.
KTouchLecture *m_lecture; ///< Pointer to the lecture data.
diff --git a/ktouch/src/ktouch.cpp b/ktouch/src/ktouch.cpp
index 08f1d0db..632aabe1 100644
--- a/ktouch/src/ktouch.cpp
+++ b/ktouch/src/ktouch.cpp
@@ -75,7 +75,7 @@ KTouch::KTouch()
setupActions();
// create the GUI reading the ui.rc file
if (!initialGeometrySet())
- resize( TQSize(700, 510).expandedTo(tqminimumSizeHint()));
+ resize( TQSize(700, 510).expandedTo(minimumSizeHint()));
setupGUI(ToolBar | Keys | StatusBar | Create);
setAutoSaveSettings();
// Read user statistics
@@ -179,10 +179,10 @@ void KTouch::keyPressEvent(TQKeyEvent *keyEvent) {
if (keyEvent->text().length() > 1) {
kdDebug() << "[KTouch::keyPressEvent] text = '" << keyEvent->text() << "'" << endl;
}
- TQChar key = keyEvent->text().at(0); // get first tqunicode character
+ TQChar key = keyEvent->text().at(0); // get first unicode character
// HACK : manually filter out known dead keys
// bool has_dead_key = true;
- switch (key.tqunicode()) {
+ switch (key.unicode()) {
case 94 : m_lastDeadKey = TQChar(uint(94)); break;
case 176 : m_lastDeadKey = TQChar(uint(176)); break;
case 180 : m_lastDeadKey = TQChar(uint(180)); break;
@@ -428,7 +428,7 @@ void KTouch::optionsPreferences() {
m_pageTraining = new KTouchPrefTrainingLayout(0, "Training");
dialog->addPage(m_pageTraining, i18n("Training Options"), "kalarm");
m_pageKeyboard = new KTouchPrefKeyboardLayout(0, "Keyboard");
- dialog->addPage(m_pageKeyboard, i18n("Keyboard Settings"), "keyboard_tqlayout");
+ dialog->addPage(m_pageKeyboard, i18n("Keyboard Settings"), "keyboard_layout");
m_pageColors = new KTouchPrefColorsLayout(0, "Colors");
dialog->addPage(m_pageColors, i18n("Color Settings"), "package_graphics");
connect(dialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(applyPreferences()));
@@ -450,12 +450,12 @@ void KTouch::optionsPreferences() {
}
// ----------------------------------------------------------------------------
-void KTouch::changetqStatusbarMessage(const TQString& text) {
+void KTouch::changeStatusbarMessage(const TQString& text) {
statusBar()->message(text);
}
// ----------------------------------------------------------------------------
-void KTouch::changetqStatusbarStats(unsigned int level_correct, unsigned int level_total, unsigned int level_words,
+void KTouch::changeStatusbarStats(unsigned int level_correct, unsigned int level_total, unsigned int level_words,
unsigned int session_correct, unsigned int session_total, unsigned int session_words)
{
statusBar()->changeItem(i18n( "Level: Correct/Total chars: %1/%2 Words: %3")
@@ -468,9 +468,9 @@ void KTouch::changetqStatusbarStats(unsigned int level_correct, unsigned int lev
void KTouch::changeKeyboard(int num) {
if (static_cast<unsigned int>(num)>=m_keyboardFiles.count()) return;
Prefs::setCurrentKeyboardFile( m_keyboardFiles[num] );
-// kdDebug() << "[KTouch::changeKeyboard] new keyboard tqlayout = " << Prefs::currentKeyboardFile() << endl;
+// kdDebug() << "[KTouch::changeKeyboard] new keyboard layout = " << Prefs::currentKeyboardFile() << endl;
m_keyboardLayoutAction->setCurrentItem(num);
- // call Apply-Preferenzes in "noisy"-mode, pop up an error if the chosen tqlayout file is corrupt
+ // call Apply-Preferenzes in "noisy"-mode, pop up an error if the chosen layout file is corrupt
m_keyboardWidget->applyPreferences(this, false);
}
// ----------------------------------------------------------------------------
@@ -528,7 +528,7 @@ bool KTouch::queryExit() {
// ----------------------------------------------------------------------------
void KTouch::resizeEvent(TQResizeEvent * event) {
- changetqStatusbarStats(m_trainer->m_levelStats.m_correctChars, m_trainer->m_levelStats.m_totalChars, m_trainer->m_levelStats.m_words,
+ changeStatusbarStats(m_trainer->m_levelStats.m_correctChars, m_trainer->m_levelStats.m_totalChars, m_trainer->m_levelStats.m_words,
m_trainer->m_sessionStats.m_correctChars, m_trainer->m_sessionStats.m_totalChars, m_trainer->m_sessionStats.m_words);
KMainWindow::resizeEvent(event);
}
@@ -561,7 +561,7 @@ void KTouch::readProperties(KConfig *config) {
m_trainer->m_teacherText = m_lecture.level(m_trainer->m_level).line(m_trainer->m_line);
m_trainer->m_studentText = config->readEntry("StudentText");
m_trainer->continueTraining();
- changetqStatusbarMessage( i18n("Restarting training session: Waiting for first keypress...") );
+ changeStatusbarMessage( i18n("Restarting training session: Waiting for first keypress...") );
// update the slide line widget
m_slideLineWidget->setNewText(m_trainer->m_teacherText, m_trainer->m_studentText);
// update all the other widgets
@@ -608,7 +608,7 @@ void KTouch::init() {
//kdDebug() << "[KTouch::init] populating file lists..." << endl;
updateFileLists(); // create lists with default lecture/keyboard/examination files/colour scheme files
//kdDebug() << "[KTouch::init] " << m_lectureFiles.count() << " lectures available" << endl;
- //kdDebug() << "[KTouch::init] " << m_keyboardFiles.count() << " keyboard tqlayouts available" << endl;
+ //kdDebug() << "[KTouch::init] " << m_keyboardFiles.count() << " keyboard layouts available" << endl;
//kdDebug() << "[KTouch::init] " << m_examinationFiles.count() << " examination files available" << endl;
if (Prefs::currentLectureFile() == "default") {
@@ -620,9 +620,9 @@ void KTouch::init() {
*/
}
- // if keyboard tqlayout (loaded by Prefs is not available (e.g. the
- // tqlayout file has been deleted) switch to default keyboard
- if (m_keyboardFiles.tqcontains(Prefs::currentKeyboardFile() )==0) {
+ // if keyboard layout (loaded by Prefs is not available (e.g. the
+ // layout file has been deleted) switch to default keyboard
+ if (m_keyboardFiles.contains(Prefs::currentKeyboardFile() )==0) {
TQString default_keyboard;
// determine locale
TQString lang = KGlobal::locale()->language();
@@ -652,18 +652,18 @@ void KTouch::init() {
}
// ----------------------------------------------------------------------------
-// Creates the tqlayout and GUI setup for a practice session
+// Creates the layout and GUI setup for a practice session
void KTouch::initTrainingSession() {
- //kdDebug() << "[KTouch::initTrainingSession] setting up tqlayouts and widgets for new training session..." << endl;
+ //kdDebug() << "[KTouch::initTrainingSession] setting up layouts and widgets for new training session..." << endl;
// Build the training area. The status widget has a fixed vertical size, the slide line and the
// keyboard grow according to their vertical stretch factors (see last argument in the constructors
// of TQSizePolicy)
TQVBox * mainLayout = new TQVBox( this );
- m_statusWidget = new KTouchtqStatus( mainLayout );
+ m_statusWidget = new KTouchStatus( mainLayout );
m_slideLineWidget = new KTouchSlideLine( mainLayout );
- m_slideLineWidget->tqsetSizePolicy( TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding, 0, 1) );
+ m_slideLineWidget->setSizePolicy( TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding, 0, 1) );
m_keyboardWidget = new KTouchKeyboardWidget( mainLayout );
- m_keyboardWidget->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding, 0, 3) );
+ m_keyboardWidget->setSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding, 0, 3) );
setCentralWidget(mainLayout);
// apply the settings to the widgets
m_slideLineWidget->applyPreferences();
@@ -710,8 +710,8 @@ void KTouch::setupActions() {
// *** Settings menu ***
KStdAction::preferences(this, TQT_SLOT(optionsPreferences()), actionCollection());
- // Setup menu entries for keyboard tqlayouts
- m_keyboardLayoutAction= new KSelectAction(i18n("&Keyboard Layouts"), 0, this, 0, actionCollection(), "keyboard_tqlayouts");
+ // Setup menu entries for keyboard layouts
+ m_keyboardLayoutAction= new KSelectAction(i18n("&Keyboard Layouts"), 0, this, 0, actionCollection(), "keyboard_layouts");
m_keyboardLayoutAction->setMenuAccelsEnabled(false);
m_keyboardLayoutAction->setItems(m_keyboardTitles);
connect (m_keyboardLayoutAction, TQT_SIGNAL(activated(int)), this, TQT_SLOT(changeKeyboard(int)));
@@ -753,7 +753,7 @@ void KTouch::updateFileLists() {
// TODO : search in i18n() directories
m_keyboardFiles = dirs->findAllResources("data","ktouch/*.keyboard");
- // remove the number tqlayout, since this is the necessary default tqlayout and will be
+ // remove the number layout, since this is the necessary default layout and will be
// added anyway
TQStringList::iterator it = m_keyboardFiles.find("number.keyboard");
if (it!=m_keyboardFiles.end()) m_keyboardFiles.remove(it);
diff --git a/ktouch/src/ktouch.h b/ktouch/src/ktouch.h
index 6b63b84e..ba5f8e56 100644
--- a/ktouch/src/ktouch.h
+++ b/ktouch/src/ktouch.h
@@ -30,7 +30,7 @@ class KToggleAction;
class KActionMenu;
class KSelectAction;
-class KTouchtqStatus;
+class KTouchStatus;
class KTouchSlideLine;
class KTouchKeyboardWidget;
class KTouchTrainer;
@@ -71,9 +71,9 @@ class KTouch : public KMainWindow {
/// Clears the statistics data.
void clearStatistics();
/// Updates the status bar text.
- void changetqStatusbarMessage(const TQString& text);
+ void changeStatusbarMessage(const TQString& text);
/// Updates the status bar statistics.
- void changetqStatusbarStats(unsigned int level_correct, unsigned int level_total, unsigned int level_words,
+ void changeStatusbarStats(unsigned int level_correct, unsigned int level_total, unsigned int level_words,
unsigned int session_correct, unsigned int session_total, unsigned int session_words);
public slots:
@@ -100,7 +100,7 @@ class KTouch : public KMainWindow {
void trainingStatistics(); ///< The action Training->Show training statistics...
void optionsPreferences(); ///< The action Settings->Configure KTouch...
/// Quick-changes the keyboard tqlayout (called from menu).
void changeKeyboard(int num);
/// Quick-changes the colour scheme used on the keyboard (called from menu).
void changeColor(int num);
@@ -110,7 +110,7 @@ class KTouch : public KMainWindow {
protected:
/// Reimplementated to save preferences and
bool queryExit();
/// Some tqlayout fixes here...
void resizeEvent(TQResizeEvent *);
/// Accepts a typed char.
void keyPressEvent(TQKeyEvent *keyEvent);
@@ -127,7 +127,7 @@ class KTouch : public KMainWindow {
/// Initialises the program during a normal startup
void init();
/// Creates the tqlayout and GUI setup for a practice session
void initTrainingSession();
/// Creates the (standard) actions and entries in the menu.
void setupActions();
@@ -153,7 +153,7 @@ class KTouch : public KMainWindow {
KSelectAction *m_keyboardColorAction;
KSelectAction *m_defaultLectureAction;
- KTouchtqStatus *m_statusWidget; ///< Pointer to the status widget on top of the main widget.
+ KTouchStatus *m_statusWidget; ///< Pointer to the status widget on top of the main widget.
KTouchSlideLine *m_slideLineWidget; ///< Pointer to the sliding line widget.
KTouchKeyboardWidget *m_keyboardWidget; ///< Pointer to the keyboard widget.
KTouchTrainer *m_trainer; ///< The training 'master' (runs the training).
@@ -170,8 +170,8 @@ class KTouch : public KMainWindow {
TQStringList m_examinationFiles; ///< A list of all default examination files.
TQStringList m_examinationTitles; ///< A list of the titles of all default examination files.
- TQStringList m_keyboardFiles; ///< A list of all default keyboard tqlayout files.
- TQStringList m_keyboardTitles; ///< A list of the titles of all default keyboard tqlayout files.
+ TQStringList m_keyboardFiles; ///< A list of all default keyboard layout files.
+ TQStringList m_keyboardTitles; ///< A list of the titles of all default keyboard layout files.
KTouchStatisticsData m_stats; ///< All user statistics are kept here.
@@ -100,7 +100,7 @@ class KTouch : public KMainWindow {
void trainingStatistics(); ///< The action Training->Show training statistics...
void optionsPreferences(); ///< The action Settings->Configure KTouch...
- /// Quick-changes the keyboard tqlayout (called from menu).
+ /// Quick-changes the keyboard layout (called from menu).
void changeKeyboard(int num);
/// Quick-changes the colour scheme used on the keyboard (called from menu).
@@ -110,7 +110,7 @@ class KTouch : public KMainWindow {
/// Reimplementated to save preferences and
bool queryExit();
- /// Some tqlayout fixes here...
+ /// Some layout fixes here...
void resizeEvent(TQResizeEvent *);
/// Accepts a typed char.
@@ -127,7 +127,7 @@ class KTouch : public KMainWindow {
/// Initialises the program during a normal startup
void init();
- /// Creates the tqlayout and GUI setup for a practice session
+ /// Creates the layout and GUI setup for a practice session
void initTrainingSession();
/// Creates the (standard) actions and entries in the menu.
diff --git a/ktouch/src/ktouchkeyboard.cpp b/ktouch/src/ktouchkeyboard.cpp
index d654d542..1e7440a5 100644
--- a/ktouch/src/ktouchkeyboard.cpp
+++ b/ktouch/src/ktouchkeyboard.cpp
@@ -34,7 +34,7 @@ void KTouchKeyboard::clear() {
}
// ----------------------------------------------------------------------------
// Loads a keyboard tqlayout (old format) from file (returns true if successful).
bool KTouchKeyboard::load(TQWidget * window, const KURL& url) {
// Ok, first download the contents as usual using the KIO lib
// File is only downloaded if not local, otherwise it's just opened
@@ -176,14 +176,14 @@ bool KTouchKeyboard::read(TQTextStream& in) {
// Loads keyboard data from file into an XML document
bool KTouchKeyboard::read(const TQDomDocument& doc) {
// clean current data
- kdDebug() << "Reading new keyboard tqlayout" << endl;
+ kdDebug() << "Reading new keyboard layout" << endl;
m_keys.clear();
m_connectors.clear();
m_title = TQString::null;
// retrieve the title
TQDomNodeList entries = doc.elementsByTagName("Title");
if (entries.count() >= 1) m_title = entries.item(0).firstChild().nodeValue();
- else m_title = i18n("untitled keyboard tqlayout");
+ else m_title = i18n("untitled keyboard layout");
kdDebug() << "Title: " << m_title << endl;
// retrieve the comment
entries = doc.elementsByTagName("Comment");
@@ -232,10 +232,10 @@ bool KTouchKeyboard::read(const TQDomDocument& doc) {
void KTouchKeyboard::write(TQDomDocument& doc) const {
TQDomElement root = doc.createElement( "KTouchKeyboard" );
doc.appendChild(root);
- // Store title and ensure that the file tqcontains a title!
+ // Store title and ensure that the file contains a title!
TQDomElement title = doc.createElement("Title");
TQDomText titleText;
- if (m_title.isEmpty()) titleText = doc.createTextNode( i18n("untitled keyboard tqlayout") );
+ if (m_title.isEmpty()) titleText = doc.createTextNode( i18n("untitled keyboard layout") );
else titleText = doc.createTextNode(m_title);
title.appendChild(titleText);
root.appendChild(title);
@@ -281,7 +281,7 @@ void KTouchKeyboard::createDefault() {
const int keyWidth = 20;
const int col = keyWidth+keySpacing;
const int row = keyHeight+keySpacing;
// First let's create the visible tqlayout.
// This means we have to create all keys that will be displayed.
// Note: purely decorative keys get a key character code of 0!
m_keys.clear();
@@ -327,7 +327,7 @@ void KTouchKeyboard::createDefault() {
m_connectors.push_back( KTouchKeyConnector('.', '.', '6', 0) );
m_title = "Number keypad";
- m_comment = "Predefined keyboard tqlayout";
+ m_comment = "Predefined keyboard layout";
m_language = TQString::null;
// language does not apply to numbers... that's one of the nice things with math :-)
m_fontSuggestions = "Monospace";
@@ -352,12 +352,12 @@ bool KTouchKeyboard::loadKeyboard(TQWidget * window, const KURL& url, TQString*
bool result = readKeyboard(target, msg);
KIO::NetAccess::removeTempFile(target);
if (!result && errorMsg!=NULL)
- *errorMsg = i18n("Could not read the keyboard tqlayout file '%1'. ").arg(url.url()) + msg;
+ *errorMsg = i18n("Could not read the keyboard layout file '%1'. ").arg(url.url()) + msg;
return result;
}
else {
if (errorMsg!=NULL)
- *errorMsg = i18n("Could not download/open keyboard tqlayout file from '%1'.").arg(url.url());
+ *errorMsg = i18n("Could not download/open keyboard layout file from '%1'.").arg(url.url());
return false;
}
}
@@ -382,7 +382,7 @@ void KTouchKeyboard::saveKeyboard(TQWidget * window, const KURL& url) {
TQTextStream out( &outfile );
out << "########################################## \n";
out << "# # \n";
- out << "# Keyboard tqlayout file for KTouch # \n";
+ out << "# Keyboard layout file for KTouch # \n";
out << "# # \n";
out << "########################################## \n";
out << "#\n";
@@ -396,7 +396,7 @@ void KTouchKeyboard::saveKeyboard(TQWidget * window, const KURL& url) {
default : out << "NormalKey "; break;
}
TQRect rect=key->frame();
- out << key->m_keyChar.tqunicode() << '\t' << key->m_keyText << '\t'
+ out << key->m_keyChar.unicode() << '\t' << key->m_keyText << '\t'
<< rect.left() << '\t' << rect.top() << '\t' << rect.width() << '\t' << rect.height() << endl;
}
@@ -408,15 +408,15 @@ void KTouchKeyboard::saveKeyboard(TQWidget * window, const KURL& url) {
}
void KTouchKeyboard::applyPreferences(TQWidget * window, bool silent) {
// let's check whether the keyboard tqlayout has changed
if (KTouchConfig().m_currentKeyboardFile!=m_currentLayout) {
- // if the tqlayout is the number tqlayout just create it and we're done
+ // if the layout is the number layout just create it and we're done
if (KTouchConfig().m_currentKeyboardFile=="number.keyboard") {
createDefaultKeyboard();
resizeEvent(NULL);
return;
}
// ok, let's load this tqlayout
if (silent) {
// during initialisation we don't want to have a message box, that's why this is silent
if (!loadKeyboard(window, KURL::fromPathOrURL( KTouchConfig().m_currentKeyboardFile )))
@@ -427,8 +427,8 @@ void KTouchKeyboard::applyPreferences(TQWidget * window, bool silent) {
else {
TQString errorMsg;
if (!loadKeyboard(window, KURL::fromPathOrURL( KTouchConfig().m_currentKeyboardFile ), &errorMsg)) {
- KMessageBox::error( 0, i18n("Error reading the keyboard tqlayout; the default number keypad will "
- "be created instead. You can choose another keyboard tqlayout in the preferences dialog."),
+ KMessageBox::error( 0, i18n("Error reading the keyboard layout; the default number keypad will "
+ "be created instead. You can choose another keyboard layout in the preferences dialog."),
errorMsg);
createDefaultKeyboard();
}
@@ -34,7 +34,7 @@ void KTouchKeyboard::clear() {
}
// ----------------------------------------------------------------------------
-// Loads a keyboard tqlayout (old format) from file (returns true if successful).
+// Loads a keyboard layout (old format) from file (returns true if successful).
bool KTouchKeyboard::load(TQWidget * window, const KURL& url) {
// Ok, first download the contents as usual using the KIO lib
@@ -281,7 +281,7 @@ void KTouchKeyboard::createDefault() {
const int col = keyWidth+keySpacing;
const int row = keyHeight+keySpacing;
- // First let's create the visible tqlayout.
+ // First let's create the visible layout.
// This means we have to create all keys that will be displayed.
// Note: purely decorative keys get a key character code of 0!
@@ -408,15 +408,15 @@ void KTouchKeyboard::saveKeyboard(TQWidget * window, const KURL& url) {
}
void KTouchKeyboard::applyPreferences(TQWidget * window, bool silent) {
- // let's check whether the keyboard tqlayout has changed
+ // let's check whether the keyboard layout has changed
if (KTouchConfig().m_currentKeyboardFile!=m_currentLayout) {
@@ -408,15 +408,15 @@ void KTouchKeyboard::saveKeyboard(TQWidget * window, const KURL& url) {
return;
}
- // ok, let's load this tqlayout
+ // ok, let's load this layout
if (silent) {
// during initialisation we don't want to have a message box, that's why this is silent
diff --git a/ktouch/src/ktouchkeyboard.h b/ktouch/src/ktouchkeyboard.h
index fd2613fe..5334c49b 100644
--- a/ktouch/src/ktouchkeyboard.h
+++ b/ktouch/src/ktouchkeyboard.h
@@ -24,7 +24,7 @@
class KURL;
/// This class stores the keyboard tqlayout and the connectivity between characters
/// and the actual keys.
class KTouchKeyboard {
public:
@@ -32,7 +32,7 @@ class KTouchKeyboard {
KTouchKeyboard() { createDefault(); }
/// Clears the keyboard (resets all data)
void clear();
/// Loads a keyboard tqlayout (old format) from file (returns true if successful).
bool load(TQWidget * window, const KURL& url);
/// Loads a lecture (in XML format) from file (returns true if successful).
bool loadXML(TQWidget * window, const KURL& url);
@@ -47,7 +47,7 @@ class KTouchKeyboard {
TQValueVector<KTouchKeyConnector> m_connectors; ///< Vector with connectivity data.
QString m_title; ///< Title of the keyboard (to appear in the menu).
- QString m_comment; ///< Comments about the creator of the keyboard tqlayout.
+ QString m_comment; ///< Comments about the creator of the keyboard layout.
QString m_language; ///< Language ID of keyboard
QString m_fontSuggestions; ///< Suggestions of fonts to be used on the keys.
@@ -24,7 +24,7 @@
class KURL;
-/// This class stores the keyboard tqlayout and the connectivity between characters
+/// This class stores the keyboard layout and the connectivity between characters
/// and the actual keys.
class KTouchKeyboard {
@@ -32,7 +32,7 @@ class KTouchKeyboard {
/// Clears the keyboard (resets all data)
void clear();
- /// Loads a keyboard tqlayout (old format) from file (returns true if successful).
+ /// Loads a keyboard layout (old format) from file (returns true if successful).
bool load(TQWidget * window, const KURL& url);
/// Loads a lecture (in XML format) from file (returns true if successful).
diff --git a/ktouch/src/ktouchkeyboardwidget.cpp b/ktouch/src/ktouchkeyboardwidget.cpp
index b8f5174f..99cc63cc 100644
--- a/ktouch/src/ktouchkeyboardwidget.cpp
+++ b/ktouch/src/ktouchkeyboardwidget.cpp
@@ -51,12 +51,12 @@ bool KTouchKeyboardWidget::loadKeyboard(TQWidget * window, const KURL& url, TQSt
bool result = readKeyboard(target, msg);
KIO::NetAccess::removeTempFile(target);
if (!result && errorMsg!=NULL)
- *errorMsg = i18n("Could not read the keyboard tqlayout file '%1'. ").arg(url.url()) + msg;
+ *errorMsg = i18n("Could not read the keyboard layout file '%1'. ").arg(url.url()) + msg;
return result;
}
else {
if (errorMsg!=NULL)
- *errorMsg = i18n("Could not download/open keyboard tqlayout file from '%1'.").arg(url.url());
+ *errorMsg = i18n("Could not download/open keyboard layout file from '%1'.").arg(url.url());
return false;
}
}
@@ -81,7 +81,7 @@ void KTouchKeyboardWidget::saveKeyboard(TQWidget * window, const KURL& url) {
TQTextStream out( &outfile );
out << "########################################## \n";
out << "# # \n";
- out << "# Keyboard tqlayout file for KTouch # \n";
+ out << "# Keyboard layout file for KTouch # \n";
out << "# # \n";
out << "########################################## \n";
out << "#\n";
@@ -95,7 +95,7 @@ void KTouchKeyboardWidget::saveKeyboard(TQWidget * window, const KURL& url) {
default : out << "NormalKey "; break;
}
TQRect rect=key->frame();
- out << key->m_keyChar.tqunicode() << '\t' << key->m_keyText << '\t'
+ out << key->m_keyChar.unicode() << '\t' << key->m_keyText << '\t'
<< rect.left() << '\t' << rect.top() << '\t' << rect.width() << '\t' << rect.height() << endl;
}
@@ -112,16 +112,16 @@ void KTouchKeyboardWidget::applyPreferences(TQWidget * window, bool silent) {
setMaximumHeight(100);
else
setMaximumHeight(10000);
// let's check whether the keyboard tqlayout has changed
if (Prefs::currentKeyboardFile() != m_currentLayout) {
- // if the tqlayout is the number tqlayout just create it and we're done
+ // if the layout is the number layout just create it and we're done
//kdDebug() << "[KTouchKeyboardWidget::applyPreferences] keyboard = " << Prefs::currentKeyboardFile() << endl;
if (Prefs::currentKeyboardFile()=="number.keyboard") {
createDefaultKeyboard();
resizeEvent(NULL);
return;
}
// ok, let's load this tqlayout
if (silent) {
// during initialisation we don't want to have a message box, that's why this is silent
if (!loadKeyboard(window, KURL::fromPathOrURL( Prefs::currentKeyboardFile() )))
@@ -132,8 +132,8 @@ void KTouchKeyboardWidget::applyPreferences(TQWidget * window, bool silent) {
else {
TQString errorMsg;
if (!loadKeyboard(window, KURL::fromPathOrURL( Prefs::currentKeyboardFile() ), &errorMsg)) {
- KMessageBox::error( 0, i18n("Error reading the keyboard tqlayout; the default number keypad will "
- "be created instead. You can choose another keyboard tqlayout in the preferences dialog."),
+ KMessageBox::error( 0, i18n("Error reading the keyboard layout; the default number keypad will "
+ "be created instead. You can choose another keyboard layout in the preferences dialog."),
errorMsg);
createDefaultKeyboard();
}
@@ -309,7 +309,7 @@ void KTouchKeyboardWidget::createDefaultKeyboard() {
updateColours();
m_currentLayout="number.keyboard";
- // create keyboard tqgeometry for new keyboard data
+ // create keyboard geometry for new keyboard data
int sp = 10;
int h = 50;
@@ -397,13 +397,13 @@ bool KTouchKeyboardWidget::readKeyboard(const TQString& fileName, TQString& erro
w=h=8; // default values for old keyboard files
m_keyList.append( new KTouchFingerKey(keyAscII, keyText, x+1, y+1, w, h) );
m_connectorList.append( KTouchKeyConnection(keyAscII, keyAscII, 0, 0) );
-// kdDebug() << "read : F : tqunicode = " << keyAscII << " char = " << TQChar(keyAscII) << endl;
+// kdDebug() << "read : F : unicode = " << keyAscII << " char = " << TQChar(keyAscII) << endl;
}
else if (keyType=="ControlKey") {
lineStream >> keyText >> x >> y >> w >> h;
m_keyList.append( new KTouchControlKey(keyAscII, keyText, x+1, y+1, w-2, h-2) );
m_connectorList.append( KTouchKeyConnection(keyAscII, keyAscII, 0, 0) );
-// kdDebug() << "read : C : tqunicode = " << keyAscII << " char = " << keyText << endl;
+// kdDebug() << "read : C : unicode = " << keyAscII << " char = " << keyText << endl;
}
else if (keyType=="NormalKey") {
int fingerCharCode;
@@ -412,12 +412,12 @@ bool KTouchKeyboardWidget::readKeyboard(const TQString& fileName, TQString& erro
// retrieve the finger key with the matching char
m_keyList.append( new KTouchNormalKey(keyAscII, keyText, x+1, y+1, w, h) );
m_connectorList.append( KTouchKeyConnection(keyAscII, keyAscII, fingerCharCode, 0) );
-// kdDebug() << "read : N : tqunicode = " << keyAscII << " char = " << TQChar(keyAscII) << endl;
+// kdDebug() << "read : N : unicode = " << keyAscII << " char = " << TQChar(keyAscII) << endl;
} else if (keyType=="HiddenKey") {
int targetChar, fingerChar, controlChar;
lineStream >> targetChar >> fingerChar >> controlChar;
m_connectorList.append( KTouchKeyConnection(keyAscII, targetChar, fingerChar, controlChar) );
-// kdDebug() << "read : H : tqunicode = " << keyAscII << " char = " << TQChar(keyAscII) << " target = " << targetChar << " finger = " << fingerChar << " control = " << controlChar << endl;
+// kdDebug() << "read : H : unicode = " << keyAscII << " char = " << TQChar(keyAscII) << " target = " << targetChar << " finger = " << fingerChar << " control = " << controlChar << endl;
}
else {
@@ -437,7 +437,7 @@ bool KTouchKeyboardWidget::readKeyboard(const TQString& fileName, TQString& erro
m_keyboardWidth = std::max(m_keyboardWidth, x+w);
m_keyboardHeight = std::max(m_keyboardHeight, y+h);
} while (!in.atEnd() && !line.isNull());
-// kdDebug() << "showing all tqunicode numbers in this file" << endl;
+// kdDebug() << "showing all unicode numbers in this file" << endl;
/* for (std::set<TQChar>::iterator it = keys.begin(); it != keys.end(); ++it)
kdDebug() << *it << endl;
*/
@@ -460,9 +460,9 @@ void KTouchKeyboardWidget::updateColours() {
TQChar targetChar = (*it).m_targetKeyChar; // this is the _base_ character of the key that needs to be highlighted
TQChar ch = (*it).m_keyChar;
-/* kdDebug() << "Key #"<<++counter<<": " << ch << "(" << ch.tqunicode() << ") "
- << "target = " << targetChar << "(" << targetChar.tqunicode() << ") "
- << "finger = " << fingerChar << "(" << fingerChar.tqunicode() << ")" << endl;
+/* kdDebug() << "Key #"<<++counter<<": " << ch << "(" << ch.unicode() << ") "
+ << "target = " << targetChar << "(" << targetChar.unicode() << ") "
+ << "finger = " << fingerChar << "(" << fingerChar.unicode() << ")" << endl;
*/
m_keyCharMap[ch] = -1;
@@ -112,16 +112,16 @@ void KTouchKeyboardWidget::applyPreferences(TQWidget * window, bool silent) {
else
setMaximumHeight(10000);
- // let's check whether the keyboard tqlayout has changed
+ // let's check whether the keyboard layout has changed
if (Prefs::currentKeyboardFile() != m_currentLayout) {
@@ -112,16 +112,16 @@ void KTouchKeyboardWidget::applyPreferences(TQWidget * window, bool silent) {
return;
}
- // ok, let's load this tqlayout
+ // ok, let's load this layout
if (silent) {
// during initialisation we don't want to have a message box, that's why this is silent
diff --git a/ktouch/src/ktouchstatisticsdata.cpp b/ktouch/src/ktouchstatisticsdata.cpp
index 25225bf3..08fdff35 100644
--- a/ktouch/src/ktouchstatisticsdata.cpp
+++ b/ktouch/src/ktouchstatisticsdata.cpp
@@ -41,7 +41,7 @@ int KTouchCharStats::missHitRatio() const {
// ----------------------------------------------------------------------------
TQTextStream& operator<<(TQTextStream &out, const KTouchCharStats &ch) {
- return (out << ch.m_char.tqunicode() << " " << ch.m_correctCount << " " << ch.m_wrongCount);
+ return (out << ch.m_char.unicode() << " " << ch.m_correctCount << " " << ch.m_wrongCount);
}
// ----------------------------------------------------------------------------
@@ -135,9 +135,9 @@ void KTouchLevelStats::write(TQDomDocument& doc, TQDomElement& root) const {
level.appendChild(e);
// add char stats
TQString char_data;
// we append for each missed char the char-tqunicode and the counters
for (std::set<KTouchCharStats>::const_iterator it=m_charStats.begin(); it!=m_charStats.end(); ++it)
- char_data += TQString(" %1 %2 %3").arg(it->m_char.tqunicode())
+ char_data += TQString(" %1 %2 %3").arg(it->m_char.unicode())
.arg(it->m_correctCount).arg(it->m_wrongCount);
e = doc.createElement("CharStats");
tn = doc.createTextNode(char_data);
@@ -302,9 +302,9 @@ void KTouchSessionStats::write(TQDomDocument& doc, TQDomElement& root) const {
session.appendChild(e);
// add char data
TQString char_data;
// we append for each missed char the char-tqunicode and the counters
for (std::set<KTouchCharStats>::const_iterator it=m_charStats.begin(); it!=m_charStats.end(); ++it)
- char_data += TQString(" %1 %2 %3").arg(it->m_char.tqunicode())
+ char_data += TQString(" %1 %2 %3").arg(it->m_char.unicode())
.arg(it->m_correctCount).arg(it->m_wrongCount);
e = doc.createElement("CharStats");
tn = doc.createTextNode(char_data);
@@ -464,7 +464,7 @@ bool KTouchStatisticsData::read(TQWidget * window, const KURL& url) {
#ifdef COMPRESSED_XML_STATISTICS
TQByteArray array;
array = infile.readAll();
- array = tqUncompress(array);
+ array = qUncompress(array);
doc.setContent( array );
#else
doc.setContent( &infile );
@@ -503,7 +503,7 @@ bool KTouchStatisticsData::write(TQWidget * window, const KURL& url) const {
TQByteArray array;
TQTextStream out(array, IO_WriteOnly);
out << doc.toString();
- array = tqCompress(array);
+ array = qCompress(array);
outfile.writeBlock(array);
#else
TQTextStream out( &outfile );
@@ -135,9 +135,9 @@ void KTouchLevelStats::write(TQDomDocument& doc, TQDomElement& root) const {
// add char stats
TQString char_data;
- // we append for each missed char the char-tqunicode and the counters
+ // we append for each missed char the char-unicode and the counters
for (std::set<KTouchCharStats>::const_iterator it=m_charStats.begin(); it!=m_charStats.end(); ++it)
@@ -302,9 +302,9 @@ void KTouchSessionStats::write(TQDomDocument& doc, TQDomElement& root) const {
// add char data
TQString char_data;
- // we append for each missed char the char-tqunicode and the counters
+ // we append for each missed char the char-unicode and the counters
for (std::set<KTouchCharStats>::const_iterator it=m_charStats.begin(); it!=m_charStats.end(); ++it)
diff --git a/ktouch/src/ktouchstatus.h b/ktouch/src/ktouchstatus.h
index a3135dc3..72bb6acc 100644
--- a/ktouch/src/ktouchstatus.h
+++ b/ktouch/src/ktouchstatus.h
@@ -22,20 +22,20 @@
/** This is the implementation of the status widget (at the top of the main view).
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
* using the updatetqStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/
-class KTouchtqStatus : public KTouchtqStatusLayout {
+class KTouchStatus : public KTouchStatusLayout {
Q_OBJECT
public:
/// Constructor
- KTouchtqStatus(TQWidget *parent);
+ KTouchStatus(TQWidget *parent);
/// Called when the preferences have changed in the configuration dialog.
void applyPreferences();
/// Sets the new characters text.
void setNewChars(const TQString& newChars);
/// Updates the level LCD and the correctness progress bar
- void updatetqStatus(unsigned int level, double correctness);
+ void updateStatus(unsigned int level, double correctness);
};
#endif // KTOUCHSTATUS_H
@@ -22,20 +22,20 @@
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
- * using the updatetqStatus() member function.
+ * using the updateStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/